require 'zip'
class LittleFinger::ServerFile
  attr_reader :username
  attr_reader :password
  attr_reader :host
  attr_reader :folder_name
  attr_reader :ftp_site

  # Retrieves zipped files from the avatax servers
  # @param file_name [String] Name of file to retrieve
  def self.fetch(file_name)
    settings = LittleFinger::Configuration.configuration[:avatax][:ftp]
    obj = LittleFinger::ServerFile.new(settings[:username], settings[:password], settings[:ftp_site], file_name)
    obj.fetch
  end

  def initialize(username, password, ftp_site, file_name)
    @username = username
    @password = password
    @ftp_site = ftp_site
    portions = @ftp_site.split("/", 2)
    @host = portions[0]
    @folder_name = ""
    @folder_name = portions[1] if portions.count > 1
    @ftp_iface = nil
    @file_name = file_name
  end

  def fetch()
    connect
    zip_file = retrieve_file(@file_name)
    unzip(zip_file)
  end

  def connect
    @ftp_iface = ftp = Net::FTP.new(@host)
    # This HAS to be done when we are connecting to the Windows FTP server for some reason.
    @ftp_iface.passive = true
    @ftp_iface.login(@username, @password)
    @ftp_iface.chdir(@folder_name) if @folder_name.present?
  end

  def retrieve_file(filename)
    out_file ="/tmp/#{filename}"
    @ftp_iface.getbinaryfile(filename, out_file)
    out_file
  end

  def unzip(zip_file)
    file_names = []
    zip_obj = Zip::File.open(zip_file)
    zip_obj.each do |one_file|
      file_name = File.join(File.dirname(zip_file), one_file.name)
      # force override
      one_file.extract(file_name) { true }
      file_names << file_name
    end
    file_names
  end
end
